"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Microsoft_IotCentral(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IOT_APPS_FIELD_NUMBER: builtins.int
    @property
    def iot_apps(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___IotApps]: ...
    def __init__(
        self,
        *,
        iot_apps: collections.abc.Iterable[global___IotApps] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["iot_apps", b"iot_apps"]) -> None: ...

global___Microsoft_IotCentral = Microsoft_IotCentral

@typing_extensions.final
class IotApps(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    SUBDOMAIN_FIELD_NUMBER: builtins.int
    TEMPLATE_FIELD_NUMBER: builtins.int
    SKU_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def identity(self) -> global___SystemAssignedServiceIdentity: ...
    location: builtins.str
    name: builtins.str
    display_name: builtins.str
    state: builtins.str
    subdomain: builtins.str
    template: builtins.str
    @property
    def sku(self) -> global___AppSkuInfo: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity: global___SystemAssignedServiceIdentity | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        display_name: builtins.str = ...,
        state: builtins.str = ...,
        subdomain: builtins.str = ...,
        template: builtins.str = ...,
        sku: global___AppSkuInfo | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identity", b"identity", "resource_info", b"resource_info", "sku", b"sku"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["display_name", b"display_name", "identity", b"identity", "location", b"location", "name", b"name", "resource_info", b"resource_info", "sku", b"sku", "state", b"state", "subdomain", b"subdomain", "tags", b"tags", "template", b"template"]) -> None: ...

global___IotApps = IotApps

@typing_extensions.final
class AppSkuInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___AppSkuInfo = AppSkuInfo

@typing_extensions.final
class SystemAssignedServiceIdentity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    type: builtins.str
    def __init__(
        self,
        *,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["type", b"type"]) -> None: ...

global___SystemAssignedServiceIdentity = SystemAssignedServiceIdentity
